/** 
 * XMLSec library
 *
 * Simple Keys Manager
 * 
 * See Copyright for the status of this software.
 * 
 * Author: Aleksey Sanin <aleksey@aleksey.com>
 */
#ifndef __XMLSEC_KEYSMGMR_H__
#define __XMLSEC_KEYSMGMR_H__    

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */ 

#include <openssl/pem.h>

#include <xmlsec/xmlsec.h>
#include <xmlsec/keys.h>

/**
 * Simple Keys Manager:
 */
typedef struct _xmlSecKeyMngr *xmlSecSimpleKeyMngrPtr;

xmlSecSimpleKeyMngrPtr	xmlSecSimpleKeyMngrCreate	(void);
void			xmlSecSimpleKeyMngrDestroy	(xmlSecSimpleKeyMngrPtr mngr);
xmlSecKeyPtr		xmlSecSimpleKeyMngrLoadPrivateKey
							(xmlSecSimpleKeyMngrPtr mngr,
							const char *keyfile,
							const char *keyPwd,
							pem_password_cb *keyPwdCallback);
xmlSecKeyPtr		xmlSecSimpleKeyMngrLoadPublicKey
							(xmlSecSimpleKeyMngrPtr mngr,
							const char *keyfile,
							const char *keyPwd,
							pem_password_cb *keyPwdCallback);
int			xmlSecSimpleKeyMngrAddCertToKey	(xmlSecKeyPtr key,
							const char *certfile);								
xmlSecKeyPtr 		xmlSecSimpleKeyMngrFindKey	(void *contex,
							 xmlSecTransformId id, 
							 xmlSecKeyType type,
						         const xmlChar *name);
int			xmlSecSimpleKeyMngrAddKey	(xmlSecSimpleKeyMngrPtr mngr, 
							 xmlSecKeyPtr key);


int			xmlSecSimpleKeyMngrLoad		(xmlSecSimpleKeyMngrPtr mngr,
							 const char *uri); 
int			xmlSecSimpleKeyMngrSave		(const xmlSecSimpleKeyMngrPtr mngr, 
							 const char *filename,
							 xmlSecKeyType type);


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __XMLSEC_KEYSMGMR_H__ */

