/** 
 * XMLSec library
 *
 * Simple X509 Manager
 *
 * See Copyright for the status of this software.
 * 
 * Author: Aleksey Sanin <aleksey@aleksey.com>
 */
#ifndef __XMLSEC_X509MNGR_H__
#define __XMLSEC_X509MNGR_H__    

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */ 

#include <openssl/x509.h>

#include <xmlsec/xmlsec.h>


/** 
 * These simple functions are provided as an example. However,
 * in most case your can use it as is.
 */
typedef struct _xmlSecSimpleX509Mngr {
    X509_STORE		*xst;
    STACK_OF(X509)	*knownCerts;
    STACK_OF(X509_CRL)	*crls;
} xmlSecSimpleX509Mngr, *xmlSecSimpleX509MngrPtr;

xmlSecSimpleX509MngrPtr	xmlSecSimpleX509MngrCreate	(int sign);
void		xmlSecSimpleX509MngrDestroy		(xmlSecSimpleX509MngrPtr mngr);
int		xmlSecSimpleX509MngrAddTrustedCert	(xmlSecSimpleX509MngrPtr mngr,
							 const char *filename);
int		xmlSecSimpleX509MngrAddCert		(xmlSecSimpleX509MngrPtr mngr,
							 const char *filename);


X509*		xmlSecSimpleX509MngrFind		(xmlSecSimpleX509MngrPtr mngr,
							 xmlChar *subjectName,
							 xmlChar *issuerName,
							 xmlChar *issuerSerial,
							 xmlChar *ski);
int		xmlSecSimpleX509MngrVerify		(xmlSecSimpleX509MngrPtr mngr,
							 X509 *cert,
							 STACK_OF(X509) *untrusted);
int		xmlSecSimpleX509MngrAddCRL		(xmlSecSimpleX509MngrPtr mngr,
							 X509_CRL *crl);


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __XMLSEC_X509MNGR_H__ */

