/** 
 * XMLSec library
 *
 * "XML Encryption" implementation
 *  http://www.w3.org/TR/xmlenc-core
 * 
 * See Copyright for the status of this software.
 * 
 * Author: Aleksey Sanin <aleksey@aleksey.com>
 */
#ifndef __XMLSEC_XMLENC_H__
#define __XMLSEC_XMLENC_H__    

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */ 
#include <stdio.h>

#include <libxml/tree.h>
#include <libxml/parser.h> 

#include <xmlsec/xmlsec.h>
#include <xmlsec/keys.h>
#include <xmlsec/transforms.h>


typedef struct _xmlEncCtx *xmlEncCtxPtr; 
typedef struct _xmlEncResult *xmlEncResultPtr; 


/** 
 * XML Encrypiton context
 */
typedef struct _xmlEncCtx {
    /* keys search context */  
    xmlSecKeyPtr		key;
    xmlSecTransformId		encryptionMethod;  
    void			*encryptionData;
    const xmlSecKeysReadContext	*keysReadContext;    
    
    /* flags */
} xmlEncCtx;

/**
 * XML Encrypiton results
 */
typedef struct _xmlEncResult {
    xmlEncCtxPtr		ctx;
    xmlNodePtr			self;
    int				encrypt;
    xmlSecTransformId		encryptionMethod;
    xmlSecKeyPtr		key;            
} xmlEncResult;

/**
 * XML Encrypiton context methods
 */
xmlEncCtxPtr		xmlEncCtxCreate			(const xmlSecKeysReadContext *keysReadContext);
void 			xmlEncCtxDestroy		(xmlEncCtxPtr ctx);


/**
 * Encryption
 */
int			xmlEncEncryptMemory		(xmlEncCtxPtr ctx,
							 xmlNodePtr tmpl,
							 const unsigned char *buf,
							 size_t size,
							 xmlEncResultPtr *result);
int			xmlEncEncryptUri		(xmlEncCtxPtr ctx,
							 xmlNodePtr tmpl,
							 const char *uri,
							 xmlEncResultPtr *result);
int			xmlEncEncryptXmlNode		(xmlEncCtxPtr ctx,
							 xmlNodePtr tmpl,
							 xmlNodePtr src,
							 xmlEncResultPtr *result);
				
/**
 * XML Enc Result
 */		
xmlEncResultPtr		xmlEncResultCreate		(xmlEncCtxPtr ctx,
							 int encrypt,
							 xmlNodePtr node);
void 			xmlEncResultDestroy		(xmlEncResultPtr result);
 	 

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __XMLSEC_XMLENC_H__ */

